@@ -19,6 +19,33 @@ use std::alloc;
 use std::ffi::CString;
 use tracy_client_sys as sys;
 
+/// Start a new Tracy span with function, file, and line determined automatically.
+///
+/// # Examples
+///
+/// Begin a span region, which will be terminated once `_span` goes out of scope:
+///
+/// ```
+/// let _span = tracy_client::span!("some span");
+/// ```
+#[macro_export]
+macro_rules! span {
+    ($name:expr) => {
+        $crate::span!($name, 62)
+    };
+    ($name:expr, $callstack_depth:expr) => {{
+        struct S;
+        let func_name = std::any::type_name::<S>();
+        $crate::Span::new(
+            $name,
+            &func_name[..func_name.len() - 3],
+            file!(),
+            line!(),
+            $callstack_depth,
+        )
+    }};
+}
+
 /// A handle representing a span of execution.
 #[cfg(feature="enable")]
 pub struct Span(
@@ -394,4 +421,12 @@ mod tests {
             PLOT.point(i as f64);
         }
     }
+
+    #[test]
+    fn span_macro() {
+        let span = span!("macro span", 42);
+        span.emit_value(42);
+        let span = span!("macro span");
+        span.emit_value(62);
+    }
 }
